
.. DO NOT EDIT.
.. THIS FILE WAS AUTOMATICALLY GENERATED BY SPHINX-GALLERY.
.. TO MAKE CHANGES, EDIT THE SOURCE PYTHON FILE:
.. "auto_examples/example_kim_SW_Si.py"
.. LINE NUMBERS ARE GIVEN BELOW.

.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        Click :ref:`here <sphx_glr_download_auto_examples_example_kim_SW_Si.py>`
        to download the full example code

.. rst-class:: sphx-glr-example-title

.. _sphx_glr_auto_examples_example_kim_SW_Si.py:


.. _tut_kim_sw:

Train a Stillinger-Weber potential
==================================

In this tutorial, we train a Stillinger-Weber (SW) potential for silicon that is archived
on OpenKIM_.

.. GENERATED FROM PYTHON SOURCE LINES 13-37

Before getting started to train the SW model, let's first install the SW model::

   $ kim-api-collections-management install user SW_StillingerWeber_1985_Si__MO_405512056662_005

.. seealso::
   This installs the model and its driver into the ``User Collection``. See
   :ref:`install_model` for more information about installing KIM models.

We are going to create potentials for diamond silicon, and fit the potentials to a
training set of energies and forces consisting of compressed and stretched diamond
silicon structures, as well as configurations drawn from molecular dynamics trajectories
at different temperatures.
Download the training set :download:`Si_training_set.tar.gz
<https://raw.githubusercontent.com/mjwen/kliff/master/examples/Si_training_set.tar.gz>`.
(It will be automatically downloaded if not present.)
The data is stored in # **extended xyz** format, and see :ref:`doc.dataset` for more
information of this format.

.. warning::
   The ``Si_training_set`` is just a toy data set for the purpose to demonstrate how to
   use KLIFF to train potentials. It should not be used to train any potential for real
   simulations.

Let's first import the modules that will be used in this example.

.. GENERATED FROM PYTHON SOURCE LINES 37-44

.. code-block:: default


    from kliff.calculators import Calculator
    from kliff.dataset import Dataset
    from kliff.loss import Loss
    from kliff.models import KIMModel
    from kliff.utils import download_dataset








.. GENERATED FROM PYTHON SOURCE LINES 45-50

Model
-----

We first create a KIM model for the SW potential, and print out all the available
parameters that can be optimized (we call this ``model parameters``).

.. GENERATED FROM PYTHON SOURCE LINES 50-55

.. code-block:: default


    model = KIMModel(model_name="SW_StillingerWeber_1985_Si__MO_405512056662_005")
    model.echo_model_params()






.. rst-class:: sphx-glr-script-out

 Out:

 .. code-block:: none


    '#================================================================================\n# Available parameters to optimize.\n# Model: SW_StillingerWeber_1985_Si__MO_405512056662_005\n#================================================================================\n\nname: A\nvalue: [15.2848479197914]\nsize: 1\n\nname: B\nvalue: [0.6022245584]\nsize: 1\n\nname: p\nvalue: [4.0]\nsize: 1\n\nname: q\nvalue: [0.0]\nsize: 1\n\nname: sigma\nvalue: [2.0951]\nsize: 1\n\nname: gamma\nvalue: [2.51412]\nsize: 1\n\nname: cutoff\nvalue: [3.77118]\nsize: 1\n\nname: lambda\nvalue: [45.5322]\nsize: 1\n\nname: costheta0\nvalue: [-0.3333333333333333]\nsize: 1\n\n'



.. GENERATED FROM PYTHON SOURCE LINES 56-70

The output is generated by the last line, and it tells us the ``name``, ``value``,
``size``, ``data type`` and a ``description`` of each parameter.

.. note::
   You can provide a ``path`` argument to the method ``echo_model_params(path)`` to
   write the available parameters information to a file indicated by ``path``.

.. note::
   The available parameters information can also by obtained using the **kliff**
   :ref:`cmdlntool`:
   ``$ kliff model --echo-params SW_StillingerWeber_1985_Si__MO_405512056662_005``

Now that we know what parameters are available for fitting, we can optimize all or a
subset of them to reproduce the training set.

.. GENERATED FROM PYTHON SOURCE LINES 70-77

.. code-block:: default


    model.set_opt_params(
        A=[[5.0, 1.0, 20]], B=[["default"]], sigma=[[2.0951, "fix"]], gamma=[[1.5]]
    )
    model.echo_opt_params()






.. rst-class:: sphx-glr-script-out

 Out:

 .. code-block:: none


    '#================================================================================\n# Model parameters that are optimized.\n#================================================================================\n\nA 1\n  5.0000000000000000e+00   1.0000000000000000e+00   2.0000000000000000e+01 \n\nB 1\n  6.0222455840000000e-01 \n\nsigma 1\n  2.0951000000000000e+00 fix \n\ngamma 1\n  1.5000000000000000e+00 \n\n'



.. GENERATED FROM PYTHON SOURCE LINES 78-111

Here, we tell KLIFF to fit four parameters ``B``, ``gamma``, ``sigma``, and ``A`` of the
SW model. The information for each fitting parameter should be provided as a list of
list, where the size of the outer list should be equal to the ``size`` of the parameter
given by ``model.echo_model_params()``. For each inner list, you can provide either one,
two, or three items.

- One item. You can use a numerical value (e.g. ``gamma``) to provide an initial guess
  of the parameter. Alternatively, the string ``'default'`` can be provided to use the
  default value in the model (e.g. ``B``).

- Two items. The first item should be a numerical value and the second item should be
  the string ``'fix'`` (e.g. ``sigma``), which tells KLIFF to use the value for the
  parameter, but do not optimize it.

- Three items. The first item can be a numerical value or the string ``'default'``,
  having the same meanings as the one item case. In the second and third items, you can
  list the lower and upper bounds for the parameters, respectively. A bound could be
  provided as a numerical values or ``None``. The latter indicates no bound is applied.

The call of ``model.echo_opt_params()`` prints out the fitting parameters that we
require KLIFF to optimize. The number ``1`` after the name of each parameter indicates
the size of the parameter.

.. note::
   The parameters that are not included as a fitting parameter are fixed to the default
   values in the model during the optimization.


Training set
------------

KLIFF has a :class:`~kliff.dataset.Dataset` to deal with the training data (and possibly
test data). For the silicon training set, we can read and process the files by:

.. GENERATED FROM PYTHON SOURCE LINES 111-117

.. code-block:: default


    dataset_path = download_dataset(dataset_name="Si_training_set")
    tset = Dataset(dataset_path)
    configs = tset.get_configs()






.. rst-class:: sphx-glr-script-out

 Out:

 .. code-block:: none

    1000 configurations read from /Users/mjwen/Applications/kliff/examples/Si_training_set




.. GENERATED FROM PYTHON SOURCE LINES 118-134

The ``configs`` in the last line is a list of :class:`~kliff.dataset.Configuration`.
Each configuration is an internal representation of a processed **extended xyz** file,
hosting the species, coordinates, energy, forces, and other related information of a
system of atoms.


Calculator
----------

:class:`~kliff.calculator.Calculator` is the central agent that exchanges information
and orchestrate the operation of the fitting process. It calls the model to compute the
energy and forces and provide this information to the `Loss function`_ (discussed below)
to compute the loss. It also grabs the parameters from the optimizer and update the
parameters stored in the model so that the up-to-date parameters are used the next time
the model is evaluated to compute the energy and forces. The calculator can be created
by:

.. GENERATED FROM PYTHON SOURCE LINES 134-139

.. code-block:: default


    calc = Calculator(model)
    calc.create(configs)






.. rst-class:: sphx-glr-script-out

 Out:

 .. code-block:: none


    [<kliff.models.kim.KIMComputeArguments object at 0x7fb20da56710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3f9d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3f850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3f290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3f5d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3ef50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3e250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3e090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3cf10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3f750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3b2d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3a250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3a150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3a050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3af10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d3ae90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d38e50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d38210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d39f50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d39250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d39190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d37450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d37290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d37390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d37610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d37510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d34f10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d31fd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d32fd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d32310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d32210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d2eb10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d2e250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d2ea50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d2ecd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d2ebd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d2ff50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d2f1d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d23f10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d23210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d23150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d231d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ceb250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7cf2110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ccb110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7cdb190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7cef1d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7cef190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7cf9a10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d12190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d16290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d11e10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d26410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d2b090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d2b190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d28790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d28290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d28510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21264cfd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21264c110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21264cb50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21264cc90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21264c7d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21264cb10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e09dd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e09250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e09190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0b090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0b110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0b210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0be90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0b0d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0b050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0b1d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0bf10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de0450d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de0451d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de0452d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de0453d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de0454d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de0455d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045650>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de0456d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de0457d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de0458d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045950>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de0459d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045a50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045ad0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045b50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045bd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045c50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045cd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045d50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045dd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045e50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045ed0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1de045f50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e07e10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272c990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272ca90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272ca10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272cb50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272cbd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272cc50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272ccd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272cd50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272cdd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272ce50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272ced0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21272cf50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799a10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799a90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799b10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799b90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799c10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799c90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799d10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799d90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799e10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799e90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212799f10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c0d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c1d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c2d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c3d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c4d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c5d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c650>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c6d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c7d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c8d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c950>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9c9d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9ca50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9cad0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9cb50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9cbd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9cc50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9ccd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9cd50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9cdd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9ce50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9ced0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7d9cf50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776a10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776a90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776b10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776b90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776c10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776c90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776d10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776d90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776e10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776e90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb212776f10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c0d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c1d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c2d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c3d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c4d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c5d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c650>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c6d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c7d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c8d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c950>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267c9d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267ca50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267cad0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267cb50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267cbd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267cc50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267ccd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267cd50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267cdd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267ce50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267ced0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21267cf50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265f990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265fa10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265fa90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265fb10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265fb90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265fc10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265fc90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265fd10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265fd90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265fe10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265fe90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21265ff10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a0d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a1d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a2d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a3d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a4d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a5d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a650>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a6d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a7d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a8d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a950>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285a9d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285aa50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285aad0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285ab50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285abd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285ac50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285acd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285ad50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285add0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285ae50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285aed0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21285af50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284f990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284fa10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284fa90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284fb10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284fb90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284fc10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284fc90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284fd10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284fd90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284fe10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284fe90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb21284ff10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c0d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c1d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c2d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c3d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c4d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c5d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c650>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c6d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c7d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c8d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c950>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0c9d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0ca50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0cad0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0cb50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0cbd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0cc50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0ccd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0cd50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0cdd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0ce50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0ced0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e0cf50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17a10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17a90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17b10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17b90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17c10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17c90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17d10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17d90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17e10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17e90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e17f10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e210d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e211d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e212d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e213d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e214d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e215d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21650>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e216d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e217d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e218d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21950>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e219d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21a50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21ad0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21b50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21bd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21c50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21cd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21d50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21dd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21e50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21ed0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e21f50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2c990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2ca10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2ca90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2cb10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2cb90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2cc10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2cc90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2cd10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2cd90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2ce10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2ce90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e2cf10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e370d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e371d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e372d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e373d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e374d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e375d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37650>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e376d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e377d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e378d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37950>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e379d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37a50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37ad0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37b50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37bd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37c50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37cd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37d50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37dd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37e50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37ed0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e37f50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43a10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43a90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43b10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43b90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43c10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43c90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43d10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43d90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43e10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43e90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e43f10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d0d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d1d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d2d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d3d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d4d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d5d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d650>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d6d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d7d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d8d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d950>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4d9d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4da50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4dad0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4db50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4dbd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4dc50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4dcd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4dd50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4ddd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4de50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4ded0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e4df50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58a10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58a90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58c10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58b90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58b10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58c90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58e10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58d90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58d10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58e90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e58f10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e630d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e631d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e632d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e633d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e634d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63650>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e635d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e636d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e637d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e638d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63a50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e639d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63950>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63ad0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63c50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63bd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63b50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63cd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63e50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63dd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63d50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63ed0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e63f50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6fa90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6fa10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6f990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6fb10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6fc90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6fc10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6fb90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6fd10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6fe90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6fe10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6fd90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e6ff10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a0d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a2d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a1d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a4d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a3d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a6d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a650>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a5d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a8d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a7d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a950>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7aad0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7aa50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7a9d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7ab50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7acd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7ac50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7abd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7ad50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7aed0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7ae50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7add0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e7af50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84b10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84a90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84a10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84b90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84d10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84c90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84c10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84d90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84f10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84e90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e84e10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f0d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f1d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f2d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f3d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f4d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f5d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f6d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f650>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f7d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f950>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f8d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8f9d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8fb50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8fad0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8fa50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8fbd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8fd50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8fcd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8fc50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8fdd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8ff50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8fed0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e8fe50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9c890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9ca10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9cb90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9cb10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9ca90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9cc10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9cd90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9cd10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9cc90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9ce10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9cf90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7e9cf10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea61d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea60d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea63d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea62d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea65d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea64d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6650>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea67d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea66d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea69d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6950>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea68d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6a50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6bd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6b50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6ad0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6c50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6dd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6d50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6cd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6e50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6fd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ea6f50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0a10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0a90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0c10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0b90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0b10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0c90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0e10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0d90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0d10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0e90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7eb0f10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb0d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb1d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb2d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb3d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb4d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb650>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb5d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb6d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb7d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb8d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebba50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb9d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebb950>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebbad0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebbc50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebbbd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebbb50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebbcd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebbe50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebbdd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebbd50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebbed0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7ebbf50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbea90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbea10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbe990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbeb10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbec90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbec10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbeb90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbed10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbee90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbee10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbed90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fbef10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc80d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc82d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc81d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc84d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8450>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc83d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc86d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8650>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc85d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8750>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc88d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8850>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc87d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8950>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8ad0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8a50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc89d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8b50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8cd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8c50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8bd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8d50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8ed0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8e50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8dd0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fc8f50>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2110>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2190>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2310>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2290>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2210>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2390>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2510>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2490>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2410>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2590>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2710>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2690>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2610>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2790>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2910>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2890>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2810>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2990>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2b10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2a90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2a10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2b90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2d10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2c90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2c10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2d90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2f10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2e90>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fd2e10>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fde050>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fde150>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fde0d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fde090>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fde1d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fde350>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fde2d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fde250>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fde3d0>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fde550>, <kliff.models.kim.KIMComputeArguments object at 0x7fb1c7fde4d0>]



.. GENERATED FROM PYTHON SOURCE LINES 140-157

where ``calc.create(configs)`` does some initializations for each
configuration in the training set, such as creating the neighbor list.


Loss function
-------------

KLIFF uses a loss function to quantify the difference between the training set data and
potential predictions and uses minimization algorithms to reduce the loss as much as
possible. KLIFF provides a large number of minimization algorithms by interacting with
SciPy_. For physics-motivated potentials, any algorithm listed on
`scipy.optimize.minimize`_ and `scipy.optimize.least_squares`_ can be used. In the
following code snippet, we create a loss of energy and forces, where the residual
function uses an ``energy_weight`` of ``1.0`` and a ``forces_weight`` of ``0.1``, and
``2`` processors will be used to calculate the loss. The ``L-BFGS-B`` minimization
algorithm is applied to minimize the loss, and the minimization is allowed to run for
a max number of 100 iterations.

.. GENERATED FROM PYTHON SOURCE LINES 157-164

.. code-block:: default


    steps = 100
    residual_data = {"energy_weight": 1.0, "forces_weight": 0.1}
    loss = Loss(calc, residual_data=residual_data, nprocs=2)
    loss.minimize(method="L-BFGS-B", options={"disp": True, "maxiter": steps})






.. rst-class:: sphx-glr-script-out

 Out:

 .. code-block:: none

    Start minimization using method: L-BFGS-B.
    Running in multiprocessing mode with 2 processes.

    Finish minimization using method: L-BFGS-B.

          fun: 0.6940780132865848
     hess_inv: <3x3 LbfgsInvHessProduct with dtype=float64>
          jac: array([ 4.66293632e-07, -4.37427870e-06,  4.10782522e-07])
      message: b'CONVERGENCE: NORM_OF_PROJECTED_GRADIENT_<=_PGTOL'
         nfev: 184
          nit: 37
         njev: 46
       status: 0
      success: True
            x: array([14.93863456,  0.58740273,  2.20146129])



.. GENERATED FROM PYTHON SOURCE LINES 165-169

The minimization stops after running for 27 steps.  After the minimization, we'd better
save the model, which can be loaded later for the purpose to do a retraining or
evaluations. If satisfied with the fitted model, you can also write it as a KIM model
that can be used with LAMMPS_, GULP_, ASE_, etc. via the kim-api_.

.. GENERATED FROM PYTHON SOURCE LINES 169-176

.. code-block:: default


    model.echo_opt_params()
    model.save("kliff_model.yaml")
    model.write_kim_model()
    # model.load("kliff_model.yaml")






.. rst-class:: sphx-glr-script-out

 Out:

 .. code-block:: none

    KLIFF trained model write to `/Users/mjwen/Applications/kliff/examples/SW_StillingerWeber_1985_Si__MO_405512056662_005_kliff_trained`




.. GENERATED FROM PYTHON SOURCE LINES 177-195

The first line of the above code generates the output.  A comparison with the original
parameters before carrying out the minimization shows that we recover the original
parameters quite reasonably. The second line saves the fitted model to a file named
``kliff_model.pkl`` on the disk, and the third line writes out a KIM potential named
``SW_StillingerWeber_1985_Si__MO_405512056662_005_kliff_trained``.

.. seealso::
   For information about how to load a saved model, see :ref:`doc.modules`.


.. _OpenKIM: https://openkim.org
.. _SciPy: https://scipy.org
.. _scipy.optimize.minimize: https://docs.scipy.org/doc/scipy/reference/generated/scipy.optimize.minimize.html
.. _scipy.optimize.least_squares: https://docs.scipy.org/doc/scipy/reference/generated/scipy.optimize.least_squares.html
.. _kim-api: https://openkim.org/kim-api/
.. _LAMMPS: https://lammps.sandia.gov
.. _GULP: http://gulp.curtin.edu.au/gulp/
.. _ASE: https://wiki.fysik.dtu.dk/ase/


.. rst-class:: sphx-glr-timing

   **Total running time of the script:** ( 1 minutes  53.831 seconds)


.. _sphx_glr_download_auto_examples_example_kim_SW_Si.py:


.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-example



  .. container:: sphx-glr-download sphx-glr-download-python

     :download:`Download Python source code: example_kim_SW_Si.py <example_kim_SW_Si.py>`



  .. container:: sphx-glr-download sphx-glr-download-jupyter

     :download:`Download Jupyter notebook: example_kim_SW_Si.ipynb <example_kim_SW_Si.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
